/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2005-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.p2p.util;

import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;

import uk.ac.standrews.cs.nds.p2p.interfaces.IHash;
import uk.ac.standrews.cs.nds.util.ErrorHandling;

/**
 * Wrapper for SHA1 hash implementation.
 *
 * @author Stuart Norcross (stuart@cs.st-andrews.ac.uk)
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public class SHA1Hash implements IHash {

    private MessageDigest sha1;

    /**
     * Initialises hash.
     */
    public SHA1Hash() {

        try {
            sha1 = MessageDigest.getInstance("SHA1");
        }
        catch (final NoSuchAlgorithmException e) {
            ErrorHandling.exceptionError(e, "couldn't load SHA1");
        }
    }

    /**
     * Generates the hash of the given data.
     *
     * @param data the data to be hashed
     * @return the result of hashing the data
     */
    @Override
    public synchronized byte[] hash(final byte[] data) {

        sha1.reset();
        sha1.update(data, 0, data.length);
        return sha1.digest();
    }

    /**
     * Returns the fixed length of the hash digest in bytes.
     *
     * @return the fixed length of the hash digest in bytes
     */
    @Override
    public int getHashSize() {

        return sha1.getDigestLength();
    }
}
