/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2005-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.remote_management;

/**
 * Interface implemented by application-specific scanners.
 * 
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public interface IHostScanner {

    /**
     * Returns the minimum cycle time between successive scans of the host list.
     * @return the minimum cycle time between successive scans of the host list, in ms
     */
    int getMinCycleTime();

    /**
     * Returns the label to be used in a user interface toggle for this scanner, or null if none required.
     * @return the label to be used in a user interface toggle
     */
    String getToggleLabel();

    /**
     * Controls whether the scanner is enabled.
     * @param enabled true if the scanner should be enabled
     */
    void setEnabled(boolean enabled);
}
