/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2005-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.util;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;

/**
 * Utility that provides input from the console.
 *
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public final class CommandLineInput {

    private static final BufferedReader READER;

    static {
        READER = new BufferedReader(new InputStreamReader(System.in));
    }

    /**
     * Prevent instantiation of utility class.
     */
    private CommandLineInput() {

    }

    /**
     * Returns the next line from the console.
     * 
     * @return the next line from the console
     */
    public static String readLine() {

        try {
            return READER.readLine();
        }
        catch (final IOException e) {
            return "";
        }
    }
}
