/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2004-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.util;

import java.util.Iterator;
import java.util.List;

/**
 * Reverse iterator over a list.
 * @param <T> the element type
 *
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public class ReverseIterator<T> implements Iterator<T> {

    private int index;
    private final List<T> list;

    /**
     * Initialises the iterator.
     * 
     * @param list the list to be reversed
     */
    public ReverseIterator(final List<T> list) {

        this.list = list;
        index = list.size() - 1;
    }

    @Override
    public boolean hasNext() {

        return index >= 0;
    }

    @Override
    public T next() {

        return list.get(index--);
    }

    @Override
    public void remove() {

        throw new UnsupportedOperationException();
    }
}
