/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2004-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.util.test;

import org.junit.Test;

import uk.ac.standrews.cs.nds.util.ActionQueue;

/**
 * Test class for {@link ActionQueue}.
 *
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public class ActionQueueTest1 {

    /**
     * Tests whether all of a set of queued actions are eventually completed.
     * It's not clear how to test timing issues given that we can't assume
     * anything about relative progress of threads.
     * 
     * @throws InterruptedException if the test thread is interrupted before completion
     */
    @Test
    public void testQueue1() throws InterruptedException {

        // Single action, single queue slot, single thread.
        final int action_delay_millis = 1000;
        final int timeout = 10000;

        testQueue(1, action_delay_millis, 0, 1, 1, timeout);
    }

    /**
     * Tests whether all of a set of queued actions are eventually completed.
     * It's not clear how to test timing issues given that we can't assume
     * anything about relative progress of threads.
     * 
     * @throws InterruptedException if the test thread is interrupted before completion
     */
    @Test
    public void testQueue2() throws InterruptedException {

        // Five actions, two threads.
        final int number_of_actions = 5;
        final int action_delay_millis = 1000;
        final int timeout = 10000;
        final int queue_capacity = 3;

        testQueue(number_of_actions, action_delay_millis, 0, queue_capacity, 2, timeout);
    }

    /**
     * Tests whether all of a set of queued actions are eventually completed.
     * It's not clear how to test timing issues given that we can't assume
     * anything about relative progress of threads.
     * 
     * @throws InterruptedException if the test thread is interrupted before completion
     */
    @Test
    public void testQueue3() throws InterruptedException {

        // Should result in some threads dying of boredom.
        final int number_of_actions = 10;
        final int action_delay_millis = 3000;
        final int submission_delay = 500;
        final int queue_capacity = 15;
        final int number_of_threads = 15;
        final int timeout = 500;

        testQueue(number_of_actions, action_delay_millis, submission_delay, queue_capacity, number_of_threads, timeout);
    }

    /*
     * Queues a number of actions and waits for them all to complete.
     * Correctness condition is simply that the method completes.
     */
    private void testQueue(final int number_of_actions, final int action_delay_millis, final int submission_delay, final int queue_capacity, final int number_of_threads, final int timeout) throws InterruptedException {

        final ActionQueue queue = new ActionQueue(queue_capacity, number_of_threads, timeout);

        // Create a number of actions.
        for (int i = 0; i < number_of_actions; i++) {

            // Queue an action that will wait for the given period.
            queue.enqueue(new TestAction(action_delay_millis));

            try {
                Thread.sleep(submission_delay);
            }
            catch (final InterruptedException e) { /* no action */
            }
        }

        // Wait for all the actions to complete.

        queue.blockUntilNoUncompletedActions();
    }
}
