/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2005-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.util.test;

import java.util.Random;

import org.junit.Test;

import uk.ac.standrews.cs.nds.util.ActionQueue;

/**
 * Test class for ActionQueue, with long running test.
 *
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public class ActionQueueTest2 {

    /**
     * Correctness condition is simply that the method completes.
     * 
     * @throws InterruptedException if the test thread is interrupted before completion
     */
    @Test
    public void testQueue() throws InterruptedException {

        final int queue_capacity = 100;
        final int max_threads = 5;
        final int idle_timeout = 10000;

        final ActionQueue queue = new ActionQueue(queue_capacity, max_threads, idle_timeout);

        final int seed = 12345678;
        final Random random = new Random(seed);

        final int number_of_iterations = 100;

        for (int i = 0; i < number_of_iterations; i++) {

            final int max_actions = 10;
            for (int j = 0; j < random.nextInt(max_actions); j++) {

                final int max_delay = 10;
                final int millis_per_sec = 1000;
                queue.enqueue(new TestAction(random.nextInt(max_delay) * millis_per_sec));
            }

            queue.blockUntilNoUncompletedActions();

            System.out.println("i: " + i);

            final int sleep_delay = 2000;
            Thread.sleep(sleep_delay);
        }
    }
}
