/***************************************************************************
 *                                                                         *
 * nds Library                                                             *
 * Copyright (C) 2005-2010 Distributed Systems Architecture Research Group *
 * University of St Andrews, Scotland                                      *
 * http://www-systems.cs.st-andrews.ac.uk/                                 *
 *                                                                         *
 * This file is part of nds, a package of utility classes.                 *
 *                                                                         *
 * nds is free software: you can redistribute it and/or modify             *
 * it under the terms of the GNU General Public License as published by    *
 * the Free Software Foundation, either version 3 of the License, or       *
 * (at your option) any later version.                                     *
 *                                                                         *
 * nds is distributed in the hope that it will be useful,                  *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           *
 * GNU General Public License for more details.                            *
 *                                                                         *
 * You should have received a copy of the GNU General Public License       *
 * along with nds.  If not, see <http://www.gnu.org/licenses/>.            *
 *                                                                         *
 ***************************************************************************/
package uk.ac.standrews.cs.nds.util.test;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import java.net.InetSocketAddress;
import java.net.UnknownHostException;

import org.junit.Test;

import uk.ac.standrews.cs.nds.util.NetworkUtil;

/**
 * Tests for {@link NetworkUtil}.
 * 
 * @author Graham Kirby (graham@cs.st-andrews.ac.uk)
 */
public class NetworkTest {

    static final String HOST_NAME = "edradour";
    static final String FULL_HOST_NAME = HOST_NAME + ".cs.st-andrews.ac.uk";
    static final int PORT = 1010;
    static final int DEFAULT_PORT = 80;

    /**
     * Tests host and port processing.
     */
    @Test
    public void testProcessHostPortParameter() {

        try {

            InetSocketAddress addr = NetworkUtil.processHostPortParameter(NetworkUtil.formatHostAddress(FULL_HOST_NAME, PORT), DEFAULT_PORT);
            assertEquals(addr.getHostName(), FULL_HOST_NAME);
            assertEquals(addr.getPort(), PORT);

            addr = NetworkUtil.processHostPortParameter(FULL_HOST_NAME + ":", DEFAULT_PORT);
            assertEquals(addr.getHostName(), FULL_HOST_NAME);
            assertEquals(addr.getPort(), DEFAULT_PORT);

            addr = NetworkUtil.processHostPortParameter(":" + PORT, DEFAULT_PORT);
            assertTrue(addr.getAddress().isSiteLocalAddress() || addr.getAddress().isLoopbackAddress());
            assertEquals(addr.getPort(), PORT);
        }
        catch (final UnknownHostException e) {
            // Occurs when running tests disconnected from network.
        }
    }

    /**
     * Tests host name processing.
     */
    @Test
    public void testExtractHostName() {

        assertEquals(NetworkUtil.extractHostName(NetworkUtil.formatHostAddress(FULL_HOST_NAME, PORT)), FULL_HOST_NAME);
        assertEquals(NetworkUtil.extractHostName(HOST_NAME + ":" + PORT), HOST_NAME);
        assertEquals(NetworkUtil.extractHostName(HOST_NAME + ":"), HOST_NAME);
        assertEquals(NetworkUtil.extractHostName(HOST_NAME), HOST_NAME);
        assertEquals(NetworkUtil.extractHostName(":" + PORT), "");
    }

    /**
     * Tests port processing.
     */
    @Test
    public void testExtractPortNumber() {

        assertEquals(NetworkUtil.extractPortNumber(NetworkUtil.formatHostAddress(FULL_HOST_NAME, PORT)), PORT);
        assertEquals(NetworkUtil.extractPortNumber(HOST_NAME + ":" + PORT), PORT);
        assertEquals(NetworkUtil.extractPortNumber(HOST_NAME + ":"), NetworkUtil.UNDEFINED_PORT);
        assertEquals(NetworkUtil.extractPortNumber(HOST_NAME), NetworkUtil.UNDEFINED_PORT);
        assertEquals(NetworkUtil.extractPortNumber(":" + PORT), PORT);
    }
}
